pub trait QueryParamValue {
// Required method
fn add_to_params(
&self,
param_name: &str,
params: &mut HashMap<String, String>,
);
}Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementations on Foreign Types
Sourceimpl QueryParamValue for &str
impl QueryParamValue for &str
Sourceimpl QueryParamValue for String
TODO: We should use a better aproach to handle these types
impl QueryParamValue for String
TODO: We should use a better aproach to handle these types